# Geo sky

A Python package to get all city, stae and country names

## Usage

Following methods can be utilized to get info..

```
from geosky import geo_plug

geo_plug.all_CountryNames()

geo_plug.all_Country_StateNames()

geo_plug.all_State_CityNames(name)# name == 'all' or stae name
geo_plug.all_State_CityNames('Odisha')
```

To uninstall execute following..

```
pip uninstall geosky

```
